Rename all arch primitives with prefix caa_
[urcu.git] / urcu-bp.c
index b0d0d44c579d6c651a2fed0b64723ddae0a71901..b457d2bc8f6e49fee5b55565107219aaf02d6ee9 100644 (file)
--- a/urcu-bp.c
+++ b/urcu-bp.c
@@ -3,7 +3,7 @@
  *
  * Userspace RCU library, "bulletproof" version.
  *
- * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
+ * Copyright (c) 2009 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  * Copyright (c) 2009 Paul E. McKenney, IBM Corporation.
  *
  * This library is free software; you can redistribute it and/or
@@ -96,9 +96,9 @@ static void mutex_lock(pthread_mutex_t *mutex)
                        exit(-1);
                }
                if (rcu_reader.need_mb) {
-                       smp_mb();
+                       cmm_smp_mb();
                        rcu_reader.need_mb = 0;
-                       smp_mb();
+                       cmm_smp_mb();
                }
                poll(NULL,0,10);
        }
@@ -123,21 +123,21 @@ void update_counter_and_wait(void)
        struct rcu_reader *index, *tmp;
 
        /* Switch parity: 0 -> 1, 1 -> 0 */
-       STORE_SHARED(rcu_gp_ctr, rcu_gp_ctr ^ RCU_GP_CTR_PHASE);
+       CAA_STORE_SHARED(rcu_gp_ctr, rcu_gp_ctr ^ RCU_GP_CTR_PHASE);
 
        /*
         * Must commit qparity update to memory before waiting for other parity
         * quiescent state. Failure to do so could result in the writer waiting
         * forever while new readers are always accessing data (no progress).
* Ensured by STORE_SHARED and LOAD_SHARED.
         */
 
        /*
* Adding a smp_mb() which is _not_ formally required, but makes the
         * model easier to understand. It does not have a big performance impact
         * anyway, given this is the write-side.
         */
-       smp_mb();
+       cmm_smp_mb();
 
        /*
         * Wait for each thread rcu_reader.ctr count to become 0.
@@ -155,7 +155,7 @@ void update_counter_and_wait(void)
                        if (wait_loops == RCU_QS_ACTIVE_ATTEMPTS)
                                usleep(RCU_SLEEP_DELAY);
                        else
-                               cpu_relax();
+                               caa_cpu_relax();
                }
        }
        /* put back the reader list in the registry */
@@ -180,7 +180,7 @@ void synchronize_rcu(void)
        /* All threads should read qparity before accessing data structure
         * where new ptr points to. */
        /* Write new ptr before changing the qparity */
-       smp_mb();
+       cmm_smp_mb();
 
        /* Remove old registry elements */
        rcu_gc_registry();
@@ -191,11 +191,11 @@ void synchronize_rcu(void)
        update_counter_and_wait();      /* 0 -> 1, wait readers in parity 0 */
 
        /*
* Adding a smp_mb() which is _not_ formally required, but makes the
         * model easier to understand. It does not have a big performance impact
         * anyway, given this is the write-side.
         */
-       smp_mb();
+       cmm_smp_mb();
 
        /*
         * Wait for previous parity to be empty of readers.
@@ -206,7 +206,7 @@ void synchronize_rcu(void)
         * Finish waiting for reader threads before letting the old ptr being
         * freed.
         */
-       smp_mb();
+       cmm_smp_mb();
 out:
        mutex_unlock(&rcu_gp_lock);
        ret = pthread_sigmask(SIG_SETMASK, &oldmask, NULL);
@@ -123,21 +123,21 @@ void update_counter_and_wait(void)
         * quiescent state. Failure to do so could result in the writer waiting
         * forever while new readers are always accessing data (no progress).
-        * Ensured by STORE_SHARED and LOAD_SHARED.
+        * Ensured by CAA_STORE_SHARED and CAA_LOAD_SHARED.
         */
 
@@ -123,21 +123,21 @@ void update_counter_and_wait(void)
 
        /*
-        * Adding a smp_mb() which is _not_ formally required, but makes the
+        * Adding a cmm_smp_mb() which is _not_ formally required, but makes the
         * model easier to understand. It does not have a big performance impact
         * anyway, given this is the write-side.
@@ -191,11 +191,11 @@ void synchronize_rcu(void)
 
        /*
-        * Adding a smp_mb() which is _not_ formally required, but makes the
+        * Adding a cmm_smp_mb() which is _not_ formally required, but makes the
         * model easier to understand. It does not have a big performance impact
         * anyway, given this is the write-side.
This page took 0.02443 seconds and 4 git commands to generate.